#pragma once
#include "SharedRuns.h"
#include "RenderTechnique.h"

/**
	@brief Base abstract class for a collection techniques.

	This is a helper class, to collect RenderTechnique instances bound to a single renderable.
	It's main task is to recieve and forward messages to each RenderTechnique.
*/
class TechniqueGroup
{
public:
	/**
		@brief Constructor.
	*/
	TechniqueGroup(void);
	

	/**
		@brief Adds an empty SharedRuns parent. 
		
		Used after creating a new TechniqueGroup.

		@param sharedRuns the SharedRun instance the RenderTechniques will use.
	*/
	void addSharedRun(SharedRuns* sharedRuns){parentSharedRuns = sharedRuns;
												parentSharedRuns->setTechniqueGroup(this);}
	/**
		@brief Retrieves the shared runs.

		@result the SharedRun instance the RenderTechniques use.
	*/
	SharedRuns* getSharedRuns(){return parentSharedRuns;}
	/**
		@brief Adds a rendertechnique to the group.

		@param technique the RenderTechnique instance to add.
	*/
	virtual void addRenderTechnique(RenderTechnique* technique)=0;
	/**
		@brief Updates all rendertechniques

		@param framenum current framenumber
	*/
	virtual void update(unsigned long frameNum) = 0;
	/**
		@brief Called after one of he shared runs changes.

		This message will be forwarded to each RenderTechique.
		
		@param runType enum describing the type of the changed run
		@param run pointer to the changed RenderingRun
	*/
	virtual void runChanged(RenderingRunType runType, RenderingRun* run) = 0;
	/**
		@brief Called after one of he shared runs updates.
		
		This message will be forwarded to each RenderTechique.
		
		@param runType enum describing the type of the updated run
		@param run pointer to the updated RenderingRun
	*/	
	virtual void runUpdated(RenderingRunType runType, RenderingRun* run) = 0;
	
	/**
		@brief Updates the connected SharedRuns boundary.
	*/
	virtual void updateBounds()
	{
		parentSharedRuns->updateBounds();
	}
	/**
		@brief Validates the connected SharedRuns instance.
	*/
	virtual void validateSharedRuns()
	{
		parentSharedRuns->validate();
	}

protected:

	/**
		@brief Pointer to the connected SharedRuns instance each technique uses.
	*/
	SharedRuns* parentSharedRuns;
};
